{
  withSystem,
  inputs,
  ...
}: {
  # perSystem = { ... }: { config.packages.hello = ...; };

  flake.nixosConfigurations.driftwood = withSystem "aarch64-linux" (
    ctx @ {
      config,
      inputs',
      ...
    }:
      inputs.nixpkgs.lib.nixosSystem {
        # Expose `packages`, `inputs` and `inputs'` as module arguments.
        # Use specialArgs permits use in `imports`.
        # Note: if you publish modules for reuse, do not rely on specialArgs, but
        # on the flake scope instead. See also https://flake.parts/define-module-in-separate-file.html
        specialArgs = {
          packages = config.packages;
          inherit inputs inputs';
        };
        modules = [
          (
            {
              config,
              lib,
              pkgs,
              ...
            }: {
              imports = [
                # Our modules
                (import ../../modules/base.nix {inherit inputs;})
                (import ../../modules/autoupdate.nix)
                (import ./configuration.nix)
                (import ./hardware.nix)
                (import ../../modules/user.nix {
                  inherit inputs;
                  mutableUsers = false;
                })
                (import ../../modules/ssh.nix)
                (import ../../modules/tailscale.nix)
                (import ./containers/conduit.nix)
                (import ./containers/hub.nix)
                (import ./containers/vtt.nix)
                (import ./headscale.nix)
                (import ./cache.nix)
              ];

              nix.settings.experimental-features = [
                "nix-command"
                "flakes"
              ];
            }
          )
        ];
      }
  );
}
